@@ -1,13 +1,13 @@
-from httpx import URL, Cookies, Headers, QueryParams, Request, Response
-from httpx._auth import AuthTypes
-from httpx._content_streams import RequestData, RequestFiles
+from httpx import URL, Cookies, Headers, HTTPError, QueryParams, Request, Response
 from httpx._models import CookieTypes, HeaderTypes, QueryParamTypes
+from httpx._types import AuthTypes, RequestData, RequestFiles
 
 __all__ = [
     "URL",
     "Cookies",
     "Headers",
     "QueryParams",
+    "HTTPError",
     "Request",
     "Response",
     "AuthTypes",
